#
# spec file for package python-rich
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-rich
Version:        14.0.0
Release:        1.1
Summary:        A Python library for rich text and beautiful formatting in the terminal
License:        MIT
URL:            https://github.com/Textualize/rich
Source:         https://github.com/Textualize/rich/archive/refs/tags/v%{version}.tar.gz#/rich-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/Textualize/rich/pull/3604 Fix test that changed with Pygments 2.19.
# and https://github.com/Textualize/rich/pull/3608 fix remaining tests with Pygments 2.19 #3604 did not fix
Patch:          pygments.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module markdown-it-py >= 2.2.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pygments >= 2.13.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-markdown-it-py >= 2.2.0
Requires:       python-pygments >= 2.13.0
Suggests:       python-ipywidgets >= 7.5.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module attrs}
# /SECTION
%python_subpackages

%description
Render rich text, tables, progress bars, syntax highlighting,
markdown and more to the terminal.

%prep
%autosetup -p1 -n rich-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/rich
%{python_sitelib}/rich-%{version}.dist-info

%changelog
* Fri May 30 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 14.0.0
  * Added
  - Added env var TTY_COMPATIBLE to override auto-detection of TTY
    support (See console.rst for details). #3675
  * Changed
  - An empty NO_COLOR env var is now considered disabled. #3675
  - An empty FORCE_COLOR env var is now considered disabled. #3675
  - Rich tracebacks will now render notes on Python 3.11 onwards
    (added with Exception.add_note) #3676
  - Indentation in exceptions won't be underlined #3678
  - Rich tracebacks will now render Exception Groups #3677
* Tue Apr 22 2025 Markéta Machová <mmachova@suse.com>
- Add test dependency on attrs
* Fri Jan 17 2025 Markéta Machová <mmachova@suse.com>
- Add pygments.patch to fix tests with Pygments 2.19
* Thu Dec  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to GitHub tarball so we can run the testsuite.
- Correct version guard for typing_extensions Requires.
- Drop Python 3.7 sections.
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 13.9.4:
  * Optimizations to cell_len which may speed up Rich / Textual
    output https://github.com/Textualize/rich/pull/3546
- update to 13.9.3:
  * Fix a broken regex that resulted in the slow path being
    chosen for some operations. This fix should result in notable
    speedups for some operations, such as wrapping text.
  * Fixed broken regex that may have resulted in poor
    performance. https://github.com/Textualize/rich/pull/3535
- update to 13.9.2:
  * A hotfix for highlighting in the table, and a fix for
    `Segment.split_cells`
  * Fixed `Table` columns not highlighting when added by
    `add_row` https://github.com/Textualize/rich/issues/3517
  * Fixed an issue with Segment.split_cells reported in Textual
    https://github.com/Textualize/textual/issues/5090
- update to 13.9.1:
  * Fixed typing_extensions dependency
- update to 13.9.0:
  * Dropped support for Python3.7
  * Rich will display tracebacks with finely grained error
    locations on python 3.11+
  * Fixed issue with Segment._split_cells
  * Fix auto detection of terminal size on Windows
  * `Text.style` now respected in Panel title/subtitle
- update to 13.8.1:
  * Added support for Python 3.13
  * Fixed infinite loop when appending Text to same instance
- update to 13.8.0:
  * Fixed `Table` rendering of box elements so "footer" elements
    truly appear at bottom of table, "mid" elements in main table
    body.
  * Fixed styles in Panel when Text objects are used for title
  * Fix pretty repr for `collections.deque`
  * Thread used in progress.track will exit if an exception
    occurs in a generator
  * Progress track thread is now a daemon thread
  * Fixed cached hash preservation upon clearing meta and links
  * Fixed overriding the `background_color` of `Syntax` not
    including padding
  * Fixed pretty printing of dataclasses with a default repr in
    Python 3.13
  * Fixed selective enabling of highlighting when disabled in the
    `Console`
  * Fixed BrokenPipeError writing an error message
  * Fixed superfluous space above Markdown tables
  * Fixed issue with record and capture interaction
  * Fixed control codes breaking in `append_tokens`
  * Fixed exception pretty printing a dataclass with missing
  * `RichHandler` errors and warnings will now use different
    colors (red and yellow)
  * Removed the empty line printed in jupyter while using
    `Progress`
  * Running tests in environment with `FORCE_COLOR` or `NO_COLOR`
    environment variables
  * ansi decoder will now strip problematic private escape
    sequences
  * Tree's ASCII_GUIDES and TREE_GUIDES constants promoted to
    class attributes
  * Adds a `case_sensitive` parameter to `prompt.Prompt`. This
    determines if the response is treated as case-sensitive.
  * Added `Console.on_broken_pipe`
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 13.7.1:
  * Fixes some character widths
* Thu Nov 16 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 13.7.0:
  * Added
    + Adds missing parameters to Panel.fit #3142
  + Fixed
    + Some text goes missing during wrapping when it contains
    double width characters #3176
    + Ensure font is correctly inherited in exported HTML #3104
    + Fixed typing for FloatPrompt.
- additional changes from 13.6.0:
  * Added Python 3.12 to classifiers.
- additional changes from 13.5.3:
  * Fixed
    + Markdown table rendering issue with inline styles and links
    [#3115]
    + Fix Markdown code blocks on a light background #3123
* Sun Aug 27 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 13.5.2:
  * Fixed
    + Fixed Text.expand_tab assertion error
- changes from version 13.5.1:
  * Fixed
    + Fix tilde character (~) not included in link regex when printing
    to console #3057
- changes from version 13.5.0:
  * Fixed
    + Fixed Text.expand_tabs not expanding spans.
    + Fixed TimeElapsedColumn from showing negative.
    + Fix for escaping strings with a trailing backslash #2987
    + Fixed exception in Markdown with partial table #3053
    + Fixed the HTML export template so that the <html> tag comes
    before the <head> tag #3021
    + Fixed issue with custom classes overwriting __eq__ #2875
    + Fix rich.pretty.install breakage in iPython #3013
  * Added
    + Added Text.extend_style method.
    + Added Span.extend method.
  * Changed
    + Text.tab_size now defaults to None to indicate that
    Console.tab_size should be used.
* Wed Jul 19 2023 ecsos <ecsos@opensuse.org>
- %%{?sle15_python_module_pythons} mut be at beginning to work.
* Sat Jul  8 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 13.4.2:
  * Changed
    + Relaxed markdown-it-py dependency
* Thu Jun  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 13.4.1:
  * Fixed typing extensions import in markdown #2979
- update to 13.4.0:
  * Added support for tables in Markdown #2977
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 13.3.5:
  * Fixed italic indent guides in SVG output
  * Fixed for `is_terminal` ignoring FORCE_COLOR
    https://github.com/Textualize/rich/pull/2923
  * Added Style.clear_meta_and_links
  * Reversed `pre` and `code` tags in base HTML format
  * Fix syntax error when building with nuitka
  * Fixed pretty printing of empty dataclass
  * Use `Console(stderr=True)` in `rich.traceback.install` to
    support io redirection.
  * Fixes superfluous spaces in html output
  * Fixed duplicate output in Jupyter
  * Filter ANSI character-encoding-change codes in
    `Text.from_ansi` parser
  * Fixes traceback failing when a frame filename is unreadable
  * Fix for live update rendering console markup
  * `rich.progress.track()` will now show the elapsed time after
    finishing the task
  * Fixed truecolor to eight bit color conversion
  * Fixed failing tests due to Pygments dependency
  * Relaxed ipywidgets
  * v13.2.0 replaces the unmaintained `commonmark` library with
    `markdown-it-py`. This new parser has a lot more capabilities
    and will allow us to implement a number of additional
    Markdown features in the future.
  * Switch Markdown parsing from commonmark to markdown-it-py
  * Fixed wrong filenames in Jupyter tracebacks
  * Added locals_hide_dunder and locals_hide_sunder to
    Tracebacks, to hide double underscore and single underscore
  * Tracebacks will now hide double underscore names from locals
    by default. Set `locals_hide_dunder=False` to restore
    previous behaviour.
  * Fixed issue with Segment.split_cells for mixed single and
    double cell widths
  * Some relatively minor fixes and improvements. The most
    significant update (and the reason for the major version
    bump) is that Rich has dropped Python3.6 support.
  * Reversed `pre` and `code` tags in base HTML format
  * Improved detection of `attrs` library, that isn't confused by
    the presence of the `attr` library.
  * Fixed issue with `locals_max_length` parameter not being
    respected in Traceback
  * Handling of broken `fileno` made more robust. Fixes
  * Fixed missing `fileno` on FileProxy
  * Bumped minimum Python version to 3.7
  * Pretty-printing of "tagged" `__repr__` results is now greedy
    when matching tags
  * `progress.track` now supports deriving total from
    `__length_hint__`
  * Add type annotation for key_separator of pretty.Node
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Nov 21 2022 Johannes Kastl <kastl@b1-systems.de>
- change Source URL to https://files.pythonhosted.org
- change Upstream URL to https://github.com/Textualize/rich
- add _service file to easily download this
- remove CHANGELOG.md, as this is not present in the PyPI tarball
- Update to 12.6.0:
  * Added
  - Parse ANSI escape sequences in pretty repr #2470
  - Add support for FORCE_COLOR env var #2449
  - Allow a max_depth argument to be passed to the install() hook #2486
  - Document using None as name in __rich_repr__ for tuple positional args #2379
  - Add font_aspect_ratio parameter in SVG export https://github.com/Textualize/rich/pull/2539/files
  - Added Table.add_section method. #2544
  * Fixed
  - Handle stdout/stderr being null #2513
  - Fix NO_COLOR support on legacy Windows #2458
  - Fix pretty printer handling of cyclic references #2524
  - Fix missing mode property on file wrapper breaking uploads via requests #2495
  - Fix mismatching default value of parameter ensure_ascii #2538
  - Remove unused height parameter in Layout class #2540
  - Fixed exception in Syntax.rich_measure for empty files
  * Changed
  - Removed border from code blocks in Markdown
* Wed Jul 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 12.5.1
  * Fixed missing typing extensions dependency on 3.9 #2386
- Release
  * Environment variables JUPYTER_COLUMNS and JUPYTER_LINES to
    control width and height of console in Jupyter
  * Markdown friendly Box style, MARKDOWN, for rendering tables
    ready to copy into markdown files
  * inspect will prefix coroutine functions with async def
  * Default width of Jupyter console size is increased to 115
  * Optimized Segment.divide
  * Style.__add__ will no longer return NotImplemented
  * Remove rich._lru_cache
  * Fix Rich clobbering cursor style on Windows #2339
  * Fix text wrapping edge case #2296
  * Allow exceptions that are raised while a Live is rendered to be
    displayed and/or processed #2305
  * Fix crashes that can happen with inspect when docstrings
    contain some special control codes #2294
  * Fix edges used in first row of tables when show_header=False
    [#2330]
  * Fix interaction between Capture contexts and
    Console(record=True) #2343
  * Fixed hash issue in Styles class #2346
  * Fixed bug in Segment.split_and_crop_lines
- Release 12.4.4
  * Added clipping per line to SVG output to avoid box characters
    overlapping
  * Optimized SVG output
- Release 12.4.3
  * Further tweaks to SVG character matrix
  * Added clip rect to SVG to prevent box characters overlapping
    bottom of terminal
- Release 12.4.2
  * Fix for SVG on Firefox
  * Removed excess margin from SVG, tweaked cell sizes to better
    render block characters
- Release 12.4.1
  * Fix for default background color in SVG export #2260
  * Changed
  * Added a keyline around SVG terminals which is visible on dark
    backgrounds
- Release 12.4.0
  * Rebuilt SVG export to create a simpler SVG that is more
    portable
  * Fix render_lines crash when render height was negative #2246
  * Add padding to Syntax constructor #2247
- Remove nonsensical python362 conditional for tests
- Fix requirements (missing typing_extensions in python38 broke
  httpx -- gh#encode/httpx#2316)
* Thu Jul  7 2022 Dirk Müller <dmueller@suse.com>
- update to 12.3.0:
  * Ability to change terminal window title
  * Added show_speed parameter to progress.track which will show the speed when the total is not known
  * Python blocks can now opt out from being rendered in tracebacks's frames,
    by setting a `_rich_traceback_omit = True` in their local scope
  * Fall back to `sys.__stderr__` on POSIX systems when trying to get the
    terminal size (fix issues when Rich is piped to another process)
  * Fixed markup escaping issue
  * Safari - Box appearing around SVG export
  * Fixed recursion error in Jupyter progress bars
  * Complex numbers are now identified by the highlighter
  * Fix crash on IDLE and forced is_terminal detection to False because IDLE
    can't do escape codes
  * Fixed missing blank line in traceback rendering
  * Fixed running Rich with the current working dir was deleted
  * Setting `total=None` on progress is now possible, and will display pulsing animation
  * Micro-optimization for Segment.divide
  * Bumped typing-extensions minimum to 4.0.0
  * Bumped minimum Python version to 3.6.3
  * Progress.open and Progress.wrap_file method to track the progress while
    reading from a file or file-like object
  * SVG export functionality
  * Adding Indonesian translation
  * Add missing `end` keyword argument to `Text.from_markup`
  * Fallback to text lexer when no lexer guessed
  * Fixed issue with decoding ANSI reset
  * Improve performance of cell_length
  * Improve performance of chop_cells
  * Fix capturing stdout on legacy Windows
  * Added options to TimeRemainingColumn to render a compact time format and
    render elapsed time when a task is finished.
  * Added ProgressColumn `MofNCompleteColumn` to display raw `completed/total`
    column (similar to DownloadColumn,
    but displays values as ints, does not convert to floats or add bit/bytes
    units).
  * Replace Colorama with win32 renderer
  * Add support for namedtuples to `Pretty`
  * In Jupyter mode make the link target be set to "\_blank"
  * Fix some issues with markup handling around "[" characters
  * Fix syntax lexer guessing.
  * Fixed Pretty measure not respecting expand_all
  * Collapsed definitions for single-character spinners, to save memory and
    reduce import time.
  * Fix print_json indent type in `__init__.py`
  * Fix error when inspecting object defined in REPL
  * Fix incorrect highlighting of non-indented JSON
  * Fixed height reset in complex renderables
  * Improved support for enum.Flag in ReprHighlighter
  * Tree now respects justify=None, i.e. won't pad to right
  * Removed rich.tabulate which was marked for deprecation
  * Deprecated rich.align.AlignValues in favor of AlignMethod
  * Add support for US spelling of "gray" in ANSI color names
  * Added `rich.diagnose.report` to expose environment debugging logic as function
  * Added classmethod `Progress.get_default_columns()` to get the default list
    of progress bar columns
  * Fixed performance issue in measuring text
  * Fixed test failures on PyPy3
  * Workaround for edge case of object from Faiss with no `__class__`
  * Add Traditional Chinese readme
  * Add `Syntax.guess_lexer`, add support for more lexers
  * Add `lexer` parameter to `Syntax.from_path` to allow for overrides
  * Workaround for edge case of object from Faiss with no `__class__`
  * Ensure `Syntax` always justifies left
  * Handle classes in inspect when methods=True
* Thu Apr 14 2022 Hui-Zhi Zhao <hui.zhi.zhao@suse.com>
- Ignore python3.6.2 for test since it doesn't support it.
* Fri Jan 14 2022 Ben Greiner <code@bnavigator.de>
- Update to 11.0.0
  * Note: as a major version bump, this version has some breaking
    changes. These changes won't affect many people, but we like to
    be strict about semver. See the release notes below.
  * Added max_depth arg to pretty printing #1585
  * Added vertical_align to Table.add_row #1590
  * Fixed issue with pretty repr in jupyter notebook #1717
  * Fix Traceback theme defaults override user supplied styles
    [#1786]
  * breaking Deprecated rich.console.RenderGroup, now named
    rich.console.Group
  * breaking Syntax.__init__ parameter lexer_name renamed to lexer
  * Syntax constructor accepts both str and now a pygments lexer
    [#1748]
- Releases 10.16.X
  * A bugfix for progress bars in Jupyter in this release. And a
    new property on Text class which exports the equivalent console
    markup.
  * Double print of progress bar in Jupyter #1737
  * Added Text.markup property #1751
- Releases 10.15.X
  * Added dynamic_progress.py to examples
  * Added ConsoleOptions.update_height
  * Fixed Padding not respecting height
  * Added Text.from_ansi method
  * Changed Some optimizations for simple strings (with only single
    cell widths)
  * Fixed issue with progress bar not rendering markup #1721
  * Fixed race condition when exiting Live #1530
  * Fix Deadlock issue #1734
- Release 10.14.0
  * Mostly fixes for edge cases. Added a rich_cast function to
    rich.protocol, which is unlikely to be used outside of Rich
    itself.
  * Fixed progress speed not updating when total doesn't change
  * Fixed superfluous new line in Status #1662
  * Fixed Windows legacy width again
  * Fixed infinite loop in set_cell_size #1682
  * Added file protocol to URL highlighter #1681
  * Added rich.protocol.rich_cast
  * Allowed __rich__ to work recursively
  * Allowed Text classes to work with sep in print #1689
- Fix dependencies with dropping python36 quirks
* Sun Nov  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to versino 10.13.0
  Added
  * Added json.dumps parameters to print_json.
  Fixed
  * Fixed an edge case bug when console module try to detect if
    they are in a tty at the end of a pytest run.
  * Fixed issue with TERM env vars that have more than one hyphen.
  * Fixed missing new line after progress bar when terminal is not
    interactive.
  * Fixed exception in IPython when disabling pprint with %%pprint.
  * Fixed issue where values longer than the console width
    produced invalid JSON.
  * Fixes trailing comma when pretty printing dataclass with last
    field repr=False.
  Changed
  * Markdown codeblocks now word-wrap #1515
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.12.0
  Updated
  * Official Py3.10 release
  Fixed
  * Fixed detection of custom repr when pretty printing dataclasses
- Update to version 10.11.0
  * Added two new options to Tracebacks, to hide framework code,
    and guard against very long tracebacks.
- Update to version 10.10.0
  * Added stdin support to rich.json
  * Fixed pretty printing of objects with fo magic with getattr.
- Update to version 10.9.0
  * This release highlights JSON keys with a different color
- Update to version 10.8.0
  * This release adds pretty printing of JSON
* Fri Aug 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.7.0
  * https://github.com/willmcgugan/rich/releases/tag/v10.7.0
* Tue May 18 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.2.1
  * Fixed panel in Markdown exploding
- Update to version 10.2.0
  Added
  * syntax for call, i.e. "Foo(bar)"
  * Console.measure as a convenient alias for Measurement.get
  * support for pretty printing attrs objects
  * mappingproxy to pretty print
  * UserDict and UserList support to pretty printer
  Changed
  * colorama init to set strip=False
  * Changed highlighter for False, True, None to not match in the
    middle of a word. i.e. NoneType is no longer highlighted as
    None
* Tue Apr  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.1.0
  * Fixed support for jupyter qtconsole and similar Jupyter
    environments.
* Tue Mar 30 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 10.0.1
  * Fixed race condition that duplicated lines in progress.
- Update to version 10.0.0
  Changed
  * Made pydoc import lazy as at least one use found it slow to
    import.
  * Modified string highlighting to not match in the middle of a
    word, so that apostrophes are not considered strings.
  * New way of encoding control codes in Segment.
  * New signature for Control class.
  * Changed Layout.split to use new Splitter class.
  * Improved layout.tree.
  * Changed default theme color for repr.number to cyan.
  * __rich_measure__ signature changed to accept ConsoleOptions
    rather than max_width.
  Added
  * Added __rich_repr__ protocol method to Pretty.
  * Added rich.region.Region.
  * Added ConsoleOptions.update_dimensions.
  * Added rich.console.ScreenUpdate.
  * Added Console.is_alt_screen.
  * Added Control.segment, Control.bell, Control.home,
    Control.move_to, Control.clear, Control.show_cursor,
    Control.alt_screen.
  * Added Console.update_screen and Console.update_screen_lines.
  * Added Layout.add_split, Layout.split_column, Layout.split_row,
    layout.refresh.
  * Added new Rich repr protocol __rich_repr__.
  Fixed
  * Fixed table style taking precedence over row style.
  * Fixed incorrect measurement of Text with new lines and
    whitespace.
  * Made type annotations consistent for various total keyword
    arguments in rich.progress and rich.progress_bar.
  * Disabled Progress no longer displays itself when starting.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 9.13.0
  Added
  * Pretty printer now supports dataclasses
  Fixed
  * Fixed Syntax background #1088
  * Fix for double tracebacks when no formatter #1079
  Changed
  * Added ws and wss to url highlighter
* Tue Mar  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 9.12.4
  Fixed
  * Fixed custom formatters with rich tracebacks in RichHandler.
  Changed
  * Allow highly compressed table cells to go to 0 width
  * Optimization to remove empty styles in various places
- Update to version 9.12.3
  Changed
  * Optimized Padding
- Update to version 9.12.2
  Added
  * Added ConsoleOptions.copy
  Changed
  * Optimized ConsoleOptions.update
- Update to version 9.12.1
  Fixed
  * Fixed deadlock in Progress
  Added
  * Added Task.finished_speed
  Changed
  * Froze TransferSpeedColumn speed when task is finished
  * Added SIGINT handler to downloader.py example
  * Optimization for large tables
- Update to version 9.12.0
  Fixed
  * Fixed issue with Syntax and missing lines in Layout
  * Fixed issue with nested markdown elements
  * Fixed new lines not invoking render hooks
  * Fixed Align setting height to child
  Changed
  * Printing a table with no columns now result in a blank line
  Added
  * Added height to Panel
- Update to version 9.11.1
  Fixed
  * Fixed table with expand=False not expanding when
    justify="center"
  * Fixed single renderable in Layout not respecting height
  * Fixed COLUMNS and LINES env var #1019
  * Layout now respects minimum_size when fixes sizes are greater
    than available space
  * HTML export now changes link underline score to match terminal.
  Changed
  * python -m rich.markdown and rich.syntax show usage with no
    file.
  Added
  * Added height parameter to Layout
  * Added python -m rich.segment
- Update to version 9.11.0
  Fixed
  * Fixed error message for tracebacks with broken __str__ #980
  * Fixed markup edge case #987
  Added
  * Added cheeky sponsorship request to test card
  * Added quiet argument to Console constructor
  * Added support for a callback function to format timestamps
    (allows presentation of milliseconds)
  * Added Console.set_alt_screen and Console.screen
  * Added height to ConsoleOptions
  * Added vertical parameter to Align
  * Added Layout class
  Changed
  * Pretty.overflow now defaults to None
  * Panel now respects options.height
  * Traceback lexer defaults to Python if no extension on source
  * Added ConsoleDimensions size attribute to ConsoleOptions so
    that size can't change mid-render
- Update to version 9.10.0
  Changed
  * Some optimizations for Text
  * Further optimized Tracebacks by not tokenizing code more that
    necessary
  * Table Column.header_style and Column.footer_style are now
    added to Table header/footer style
* Mon Jan 25 2021 Ben Greiner <code@bnavigator.de>
- Update to version 9.9.0
  Changed
  * Extended Windows palette to 16 colors
  * Modified windows palette to Windows 10 colors
  * Change regex for attrib_name to be more performant
  * Optimized traceback generation
  Fixed
  * Fix double line tree guides on Windows
  * Fixed Tracebacks ignoring initial blank lines
  * Partial fix for tracebacks not finding source after chdir
  Added
  * Added post_style argument to Segment.apply_style
- Changelog for 9.8.2
  * Fixed deadlock in live #927
- Changelog for 9.8.1
  * Fixed rich.inspect failing with attributes that claim to be
    callable but aren't #916
- Changelog for 9.8.0
  Added
  * Added rich_measure for tree
  * Added rich.align.VerticalCenter
  Changed
  * The style argument on Align now applies to background only
  * Changed display of progress bars in no_color mode for
    clarity
  * Console property size will fall back to getting the
    terminal size of stdout it stdin fails, this allows size
    to be correctly determined when piping
  Fixed
  * Fixed panel cropping when shrunk too bar
  * Allow passing markdown over STDIN when using python -m
    rich.markdown
  * Fix printing MagicMock.mock_calls #903
- Changelog for 9.7.0
  * Added rich.tree
  * Added no_color argument to Console
- Changelog for 9.6.2
  * Fixed markup escaping edge case #878
  * Double tag escape, i.e. "\\[foo]" results in a
    backslash plus [foo] tag
  * Fixed header_style not applying to headers in
    positional args #953
- Changelog for 9.6.1
  * Fixed encoding error on Windows when loading code for
    Tracebacks
- Changelog for 9.6.0
  Changed
  * MarkupError exception raise from None to omit internal
    exception
  * Factored out RichHandler.render and
    RichHandler.render_message for easier extending
  * Display pretty printed value in rich.inspect
  Added
  * Added Progress.TimeElapsedColumn
  * Added IPython support to pretty.install
  Fixed
  * Fixed display of locals in Traceback for stdin
- Add dataclasses BuildRequires for python 3.6 builds
* Fri Dec 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 9.5.1
  * Fixed hex number highlighting
- Update to version 9.5.0
  Changed
  * If file is not specified on Console then the Console.file will
    return the current sys.stdout. Prior to 9.5.0 sys.stdout was
    cached on the Console, which could break code that wrapped
    sys.stdout after the Console was constructed.
  * Changed Color.__str__ to not include ansi codes
  * Changed Console.size to get the terminal dimensions via
    sys.stdin. This means that if you set file to be an
    io.StringIO file (for example) then the width will be set to
    the current terminal dimensions and not a default of 80.
  Added
  * Added stderr parameter to Console
  * Added rich.reconfigure
  * Added Color.__rich__
  * Added Console.style parameter
  * Added Table.highlight parameter to enable highlighting ofcells
  * Added Panel.highlight parameter to enable highlighting of panel
    title
  * Added highlight to ConsoleOptions
  Fixed
  * Fixed double output in rich.live #485
  * Fixed Console.out highlighting not reflecting defaults #827
  * FileProxy now raises TypeError for empty non-str arguments #828
- Update to version 9.5.0
  Added
  * Added rich.live #382
  * Added algin parameter to Rule and Console.rule
  * Added rich.Status class and Console.status
  * Added getitem to Text
  * Added style parameter to Console.log
  * Added rich.diagnose command
  Changed
  * Table.add_row style argument now applies to entire line and not
    just cells
  * Added end_section parameter to Table.add_row to force a line
    underneath row
  Fixed
  * Fixed suppressed traceback context #468
- Update to version 9.3.0
  Added
  * Added get_datetime parameter to Console, to allow for
    repeatable tests
  * Added get_time parameter to Console
  * Added rich.abc.RichRenderable
  * Added expand_all to rich.pretty.install()
  * Added locals_max_length, and locals_max_string to Traceback and
    logging.RichHandler
  * Set defaults of max_length and max_string for Traceback to 10
    and 80
  * Added disable argument to Progress
  Changed
  * Reformatted test card (python -m rich)
  Fixed
  * Fixed redirecting of stderr in Progress
  * Fixed broken expanded tuple of one #445
  * Fixed justify argument not working in console.log #460
- Update to version 9.2.0
  Added
  * Added tracebacks_show_locals parameter to RichHandler
  * Added max_string to Pretty
  * Added rich.ansi.AnsiDecoder
  * Added decoding of ansi codes to captured stdout in Progress
  * Added expand_all to rich.pretty.pprint
  Changed
  * Applied dim=True to indent guide styles
  * Factored out RichHandler.get_style_and_level to allow for
    overriding in subclasses
  * Hid progress bars from html export
  * rich.pretty.pprint now soft wraps
* Tue Oct 27 2020 Benjamin Greiner <code@bnavigator.de>
- Kill dephell dependency
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 9.1.0
  * New option to render 'indent guides' in Syntax and pretty
    printing.
  * Added a max_length argument to pretty printing which will
    truncate containers longer than a certain length.
- Update to version 9.0.0
  * Added a new pager method which will pipe any console output
    in to the system 'pager'.
  * There's also a new Bar renderable you could use to display a
    chart in a table. See bars.py for an example of how to use it.
* Sat Sep 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.1.0
  Added
  * Added Console.begin_capture, Console.end_capture and
    Console.capture
  * Added Table.title_justify and Table.caption_justify
  Changed
  * Improved formatting of exceptions
  * Enabled Rich exceptions in logging https://github.com/taliraj
  * UTF-8 encoding is now mentioned in HTML head section
  Removed
  * Removed line_numbers argument from traceback.install, which
    was undocumented and did nothing
* Fri Sep 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 7.0.0
  Added
  * New ansi_dark and ansi_light themes
  * Added Text.append_tokens for fast appending of string + Style
    pairs
  * Added Text.remove_suffix
  * Added Text.append_tokens
  Changed
  * Text.tabs_to_spaces was renamed to Text.expand_tabs, which
    works in place rather than returning a new instance
  * Renamed Column.index to Column._index
  * Optimized Style.combine and Style.chain
  * Optimized text rendering by fixing internal cache mechanism
  * Optimized hash generation for Styles
* Fri Sep 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 6.1.1
  Added
  * Added ipv4 and ipv6 to ReprHighlighter
  Changed
  * The # sign is included in url highlighting
  Fixed
  * Fixed force-color switch in rich.syntax and rich.markdown
    commands
* Tue Sep  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 6.1.1
  Added
  * Inspect now adds def to signature of methods. Not strictly
    necessary, but I think it helps distinguish methods from data.
  Changed
  * Restored "def" in inspect signature
* Mon Sep  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 6.1.0
  Added
  * New inspect module
  * Added os._Environ to pretty print
  Fixed
  * Prevented recursive renderables from getting stuck
  Changed
  * force_terminal and force_jupyter can now be used to force the
    disabled state, or left as None to auto-detect.
  * Panel now expands to fit title if supplied
* Tue Aug 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 6.0.0
  Fixed
  * Fixed use of __rich__ cast
  Changed
  * New algorithm to pretty print which fits more on a line if
    possible
  * Deprecated character parameter in Rule and Console.rule, in
    favor of characters
  * Optimized Syntax.from_path to avoid searching all lexers, which
    also speeds up tracebacks
  Added
  * Added soft_wrap flag to Console.print
* Sat Aug 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 5.2.1
  * Fixed underscore with display hook
- Update to version 5.2.0
  * Added crop argument to Console.print
  * Added "ignore" overflow method
  * Added multiple characters per rule
- Update to version 5.1.2
  * Further optimized pretty printing ~5X.
- Update to version 5.1.1
  * Optimized pretty printing ~3X faster
- Update to version 5.1.0
  Added
  * Added Text.cell_len
  * Added helpful message regarding unicode decoding errors
  * Added display hook with pretty.install()
  Fixed
  * Fixed deprecation warnings re backslash
  * Fixed repr highlighting of scientific notation, e.g. 1e100
  Changed
  * Implemented pretty printing, and removed pprintpp from
    dependencies
  * Optimized Text.join
* Sat Aug  8 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v5.0.0
  * Change to console markup syntax to not parse Python structures
    as markup, i.e. `[1,2,3]` is treated as a literal, not a tag.
  * Standard color numbers syntax has changed to `"color(<number>)"`
    so that `[5]` (for example) is considered a literal.
  * Markup escape method has changed from double brackets to
    preceding with a backslash, so `foo[[]]` would be `foo\[bar]`
- From v4.2.2
  * Added thread to automatically call update() in progress.track().
    Replacing previous adaptive algorithm.
  * Second attempt at working around https://bugs.python.org/issue37871
* Fri Jul 31 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.2.1
  - Added show_time and show_level parameters to RichHandler https://github.com/willmcgugan/rich/pull/182
  - Fixed progress.track iterator exiting early https://github.com/willmcgugan/rich/issues/189
  - Added workaround for Python bug https://bugs.python.org/issue37871, fixing https://github.com/willmcgugan/rich/issues/186
  - Set overflow=fold for log messages https://github.com/willmcgugan/rich/issues/190
  - Fixed missing new lines https://github.com/willmcgugan/rich/issues/178
  - Fixed Progress.track https://github.com/willmcgugan/rich/issues/184
  - Remove control codes from exported text https://github.com/willmcgugan/rich/issues/181
  - Implemented auto-detection and color rendition of 16-color mode
  - Optimized progress.track for very quick iterations
  - Force default size of 80x25 if get_terminal_size reports size of 0,0
  - Added markup switch to RichHandler https://github.com/willmcgugan/rich/issues/171
  - Change signature of Text.stylize to accept style first
  - Remove Text.stylize_all which is no longer necessary
  - Fixed rendering of Confirm prompt https://github.com/willmcgugan/rich/issues/170
* Wed Jul 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4.1
  * Fixed incorrect default of expand in Table.grid
- Update to version 3.4.0
  Added
  * Added stream parameter to Console.input
  * Added password parameter to Console.input
  * Added description parameter to Progress.update
  * Added rich.prompt
  * Added detecting 'dumb' terminals
  * Added Text.styled alternative constructor
  Fixes
  * Fixed progress bars so that they are readable when color is
    disabled
- Update to version 3.3.2
  Changed
  * Optimized Text.pad
  Added
  * Added rich.scope
  * Change log_locals to use scope.render_scope
  * Added title parameter to Columns
* Mon Jul 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3.1
  Added
  * box.ASCII_DOUBLE_HEAD
  Changed
  * Removed replace of -- --- ... from Markdown, as it made it
    impossible to include CLI info
- Update to version 3.3.0
  Added
  * Added title and title_align options to Panel
  * Added pad and width parameters to Align
  * Added end parameter to Rule
  * Added Text.pad and Text.align methods
  * Added leading parameter to Table
- Update to version 3.2.0
  Added
  * Added Align.left Align.center Align.right shortcuts
  * Added Panel.fit shortcut
  * Added align parameter to Columns
  Fixed
  * Align class now pads to the right, like Text
  * ipywidgets added as an optional dependency
  * Issue with Panel and background color
  * Fixed missing __bool__ on Segment
  Changed
  * Added border_style argument to Panel (note, style now applies
    to interior of the panel)
- Update to version 3.1.0
  Changed
  * Progress bars now work in Jupyter
  Added
  * Added refresh_per_second to progress.track
  * Added styles to BarColumn and progress.track
- Update to version 3.0.5
  Fixed
  * Fixed Windows version number require for truecolor
- Update to version 3.0.4
  Changed
  * More precise detection of Windows console
- Update to version 3.0.3
  Fixed
  * Fixed edge case with wrapped and overflowed text
  Changed
  * New algorithm for compressing table that priorities smaller
    columns
  Added
  * Added safe_box parameter to Console constructor
* Thu Jul  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.2
  Added
  * Added rich.styled.Styled class to apply styles to renderable
  * Table.add_row now has an optional style parameter
  * Added table_movie.py to examples
  Changed
  * Modified box options to use half line characters at edges
  * Non no_wrap columns will now shrink below minimum width if
    table is compressed
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  Added
  * Added box.ASCII2
  * Added markup argument to logging extra
  Changed
  * Setting a non-None width now implies expand=True
* Mon Jun 29 2020 Martin Hauke <mardnh@gmx.de>
- Use dephell
* Mon Jun 29 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 3.0.0
